@@ -17,5 +17,5 @@ EOF
 
 $CC -B. -o $t/exe $t/a.o -L$t -Wl,--as-needed -lbar -lfoo
 readelf -W --dynamic $t/exe > $t/log2
-grep -q libbar $t/log2
-grep -q libfoo $t/log2
+grep libbar $t/log2
+not grep libfoo $t/log2
